@@ -64,20 +64,6 @@ sub listFiles($)
     return @Files;
 }
 
-sub listPaths($)
-{
-    my $Path = $_[0];
-    return () if(not $Path);
-    
-    my @Paths = ();
-    
-    foreach my $F (listDir($Path)) {
-        push(@Paths, $Path."/".$F);
-    }
-    
-    return @Paths;
-}
-
 sub getFilename($)
 { # much faster than basename() from File::Basename module
     if($_[0] and $_[0]=~/([^\/\\]+)[\/\\]*\Z/) {
@@ -134,15 +120,11 @@ sub getSiteProtocol($)
     return "";
 }
 
-sub getSite($) {
-    return getSiteProtocol($_[0]).getSiteAddr($_[0]);
-}
-
 sub extractPackage($$)
 {
     my ($Path, $OutDir) = @_;
     
-    if($Path=~/\.(tar\.\w+|tgz|tbz2|txz)\Z/i) {
+    if($Path=~/\.(tar\.\w+|tgz|tbz2)\Z/i) {
         return "tar -xf $Path --directory=$OutDir";
     }
     elsif($Path=~/\.zip\Z/i) {
@@ -158,9 +140,10 @@ sub isHeader($)
     return ($Path=~/\.(h|hh|hp|hxx|hpp|h\+\+|tcc)\Z/i);
 }
 
-sub checkCmd($)
+sub check_Cmd($)
 {
     my $Cmd = $_[0];
+    return 0 if(not $Cmd);
     
     if(-x $Cmd) {
         return 1;
