@@ -1,7 +1,7 @@
 ##################################################################
 # Module for ABI Monitor to compare library versions
 #
-# Copyright (C) 2017 Andrey Ponomarenko's ABI Laboratory
+# Copyright (C) 2016 Andrey Ponomarenko's ABI Laboratory
 #
 # Written by Andrey Ponomarenko
 #
@@ -299,16 +299,9 @@ sub cmpVersions_P($$$)
     return cmpVersions($A, $B);
 }
 
-sub skipVersion(@)
+sub skipVersion($$)
 {
-    my $V = shift(@_);
-    my $Profile = shift(@_);
-    
-    my $MinCheck = 1;
-    
-    if(@_) {
-        $MinCheck = shift(@_);
-    }
+    my ($V, $Profile) = @_;
     
     if(defined $Profile->{"SkipVersions"})
     {
@@ -316,7 +309,7 @@ sub skipVersion(@)
         
         foreach my $E (@Skip)
         {
-            if($E=~/[\*\+\[\(\|\\]/)
+            if($E=~/[\*\+\(\|\\]/)
             { # pattern
                 if($V=~/\A$E\Z/) {
                     return 1;
@@ -327,54 +320,7 @@ sub skipVersion(@)
             }
         }
     }
-    
-    if(defined $Profile->{"KeepMiniMult"})
-    {
-        my @KeepMult = @{$Profile->{"KeepMiniMult"}};
-        
-        if(my $Mini = getVerNum($V, 2))
-        {
-            my $Keep = 0;
-            
-            foreach my $K (@KeepMult)
-            {
-                if($Mini % $K == 0)
-                {
-                    $Keep = 1;
-                    last;
-                }
-            }
-            
-            if(not $Keep) {
-                return 1;
-            }
-        }
-    }
-    
-    if(defined $Profile->{"KeepMicroMult"})
-    {
-        my @KeepMult = @{$Profile->{"KeepMicroMult"}};
-        
-        if(my $Micro = getVerNum($V, 3))
-        {
-            my $Keep = 0;
-            
-            foreach my $K (@KeepMult)
-            {
-                if($Micro % $K == 0)
-                {
-                    $Keep = 1;
-                    last;
-                }
-            }
-            
-            if(not $Keep) {
-                return 1;
-            }
-        }
-    }
-    
-    if(defined $Profile->{"SkipOdd"})
+    elsif(defined $Profile->{"SkipOdd"})
     {
         if($V=~/\A\d+\.(\d+)/)
         {
@@ -385,14 +331,11 @@ sub skipVersion(@)
         }
     }
     
-    if($MinCheck)
+    if(my $Min = $Profile->{"MinimalVersion"})
     {
-        if(my $Min = $Profile->{"MinimalVersion"})
+        if(cmpVersions_P($V, $Min, $Profile)==-1)
         {
-            if(cmpVersions_P($V, $Min, $Profile)==-1)
-            {
-                return 1;
-            }
+            return 1;
         }
     }
     
@@ -492,20 +435,13 @@ sub getVersionType($$)
     
     if(defined $Profile->{"LetterReleases"})
     {
-        if($Version=~/\A[\d\.\-]+[a-z]{0,2}\Z/i
+        if($Version=~/\A[\d\.\-]+[a-z]*\Z/i
         and index($Version, "beta")==-1)
         {
             return "release";
         }
     }
     
-    if(defined $Profile->{"NumericBeta"})
-    {
-        if($Version=~/\A\d+\.\d+\.9\d+(|\.\d+)\Z/i) {
-            return "beta";
-        }
-    }
-    
     if(checkReleasePattern($Version, $Profile)) {
         return "release";
     }
@@ -570,33 +506,19 @@ sub getVersionType($$)
     return "unknown";
 }
 
-sub getMajor($$)
+sub getMajor($)
 {
-    my ($V, $L) = @_;
+    my $V = $_[0];
     
-    $V=~s/[\-_]/./g;
+    $V=~s/\-/./;
     
     my @P = split(/\./, $V);
     
-    if($#P>=$L) {
-        return join(".", splice(@P, 0, $L));
+    if($#P>1) {
+        pop(@P);
     }
-    return $V;
-}
-
-sub getVerNum($$)
-{
-    my ($V, $N) = @_;
     
-    $V=~s/[\-_]/./g;
-    
-    my @P = split(/\./, $V);
-    
-    return $P[$N-1];
-}
-
-sub getVDepth($) {
-    return $_[0]=~tr!\.!!;
+    return join(".", @P);
 }
 
 return 1;
